#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# Copyright (C) 2021 tribe29 GmbH - License: GNU General Public License v2
# This file is part of Checkmk (https://checkmk.com). It is subject to the terms and
# conditions defined in the file COPYING, which is part of this source code package.



from .agent_based_api.v1 import *

import pprint

rki_covid_default_params = {
        'max_incidence': (35, 50),
        }

def parse_rki_covid(string_table):
    parsed_data = []

    for line in string_table:
        county = {}
        county['name'] = line[0]

        kv_data = line[1:]
        metrics = {}
        for kv in kv_data:
            key, value = kv.split("=")
            metrics[key] = float(value)

        county['metrics'] = metrics

        parsed_data.append(county)

    return parsed_data


def discover_rki_covid(section):
    for county in section:
        yield Service(item=county['name'])


def check_rki_covid(item, params, section):
    for county in section:
        if county['name'] == item:

            for key in county['metrics']:

                # weekIncidence=50.9, count=1962.0, casesPer100k=1722.1, deaths=52.0
                value = county['metrics'][key]
                warn, crit = params['max_incidence']

                if key == 'weekIncidence':
                    if value > crit: # crit
                        s = State.CRIT
                        suffix = " (warn/crit at %.1f/%.1f)" % (warn, crit)
                    elif value > warn: # warn
                        s = State.WARN
                        suffix = " (warn/crit at %.1f/%.1f)" % (warn, crit)
                    else:
                        s = State.OK
                        suffix = ""

                    yield Result(state=s, summary="%s=%.1f%s" % (key, value, suffix))
                    yield Metric("rki_covid_"+key, value, levels=(warn, crit))

                else:
                    yield Result(state=State.OK, summary="%s=%.0f" % (key, value))
                    yield Metric("rki_covid_"+key, value)

            return


register.agent_section(
        name="rki_covid",
        parse_function=parse_rki_covid,
)

register.check_plugin(
        name="rki_covid",
        service_name="Covid-19 in %s",
        discovery_function=discover_rki_covid,
        check_function=check_rki_covid,
        check_default_parameters=rki_covid_default_params,
        check_ruleset_name="rki_covid",
)

